"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.authorizeAsync = exports.authorizeSync = exports.generateVerificationToken = exports.validatePassword = exports.hashPassword = void 0;
const bcryptjs_1 = __importDefault(require("bcryptjs"));
const crypto_1 = __importDefault(require("crypto"));
const str_1 = require("./str");
const types_1 = require("../types");
const hashPassword = async (plainTextPassword) => {
    const salt = await bcryptjs_1.default.genSalt(10);
    return await bcryptjs_1.default.hash(plainTextPassword, salt);
};
exports.hashPassword = hashPassword;
const validatePassword = async (plainText, hash) => await bcryptjs_1.default.compare(plainText, hash);
exports.validatePassword = validatePassword;
const generateVerificationToken = () => `${(0, str_1.generateUuid)()}-${crypto_1.default.randomBytes(32).toString('hex')}`;
exports.generateVerificationToken = generateVerificationToken;
const authorizeSync = (authFunc, error) => {
    if (!authFunc()) {
        throw new types_1.InsufficientPermissionError(error);
    }
};
exports.authorizeSync = authorizeSync;
const authorizeAsync = async (authFunc, error) => {
    if (!(await authFunc())) {
        throw new types_1.InsufficientPermissionError(error);
    }
};
exports.authorizeAsync = authorizeAsync;
